'****************************************************************************
' Developed & Written by Greg Cook --- April 20, 2000
' Email: greg_cook@bigoot.com
' Web site: http://www.bigfoot.com/~greg_cook
'
' This script is FREE for your use, so please use and share with others
' as you see fit.
'
' This script is used to rename or copy a file, moving or copying it from a
' specified source to a specified destination. The destination can be user
' specified, today's date, today's time, file's date, or file's time.
'
' The intention is to allow users to create "short-cuts" to this script
' with one of the specified destination arguments allowing them to quickly
' rename a specified file to another specified name, to today's date, or
' to it's last modified date. It is a good application for using in a scheduler
' for files that are recreated or updated on a regular basis.
'
' Syntax:
'
' RenameIt.vbs arg1 arg2 arg3 arg4
'
' arg1 = Source filename
' arg2 = Destination filename or path (use path as last character to denote path)
' arg3 = 0 = copy
'      = 1 = move
' arg4 = not supplied = copy/rename source file to file's last modified date
'      = filesdate = copy/rename source file to file's last modified date
'      = todaysdate means copy/rename file to today's date
'      = filestime = copy/rename file to file's time
'      = filesdate means copy/rename file to today's time
'
' Example "short-cut" or "Run" usage:
'
' To copy it to it's last modified date use the following, replacing the
' first and second arguments with your filename and folder (the backslash
' denotes folder):
' C:\Scripts\RenameIt.vbs "C:\Scripts\xxx1.txt" "C:\Scripts\" 0 filesdate
'
' To copy it to today's date use the following, replacing the first and
' second arguments with your filename and folder (the backslash denote
' folder):
' C:\Scripts\RenameIt.vbs "C:\Scripts\xxx1.txt" "C:\Scripts\" 0 todaysdate
'
' To copy it to a name you specify use the following, replacing the first
' and second arguments with your filenames:
' C:\Scripts\RenameIt.vbs "C:\Scripts\xxx1.txt" "C:\Scripts\NewName.txt" 0
'
' If you wish to move it instead of copy, change the third argument to 1,
' instead of 0.
'
' If you do not supply the source or destination, you will be prompted for
' them, and the file will be named according to the destination you specify,
' and/or it's last modified date.
'
' If you are interested in learning about VBScript (or JavaScript) check out:
' http://msdn.microsoft.com/scripting/
'
' This software is provided AS IS without warranty of any kind including but
' not limited to the implied warranties of merchantability and fitness for a
' particular purpose. The publisher assumes no liability for any alleged or
' actual damages arising from the use of this program. (Some states do not
' allow the exclusion of implied warranties, so the exclusion may not apply
' to you.)
'****************************************************************************

'Return the specified date as year-month-day e.g. 2000-04-08
Function FormatThisDate(dtmDate)
  On Error Resume Next

  Dim strDay
  Dim strMonth
  Dim strYear

  strDay = Day(dtmDate)
  strMonth = Month(dtmDate)
  strYear = Year(dtmDate)

  If Len(strDay) = 1 Then
    strDay = "0" & strDay
  End If

  If Len(strMonth) = 1 Then
    strMonth = "0" & strMonth
  End If

  FormatThisDate = strYear & "-" & strMonth & "-" & strDay
End Function

Sub LogStatus(strStatus)
  On Error Resume Next
  objLogFile.Write strStatus & "..." & vbNewLine
End Sub

'Standard forced exit procedure
Sub ExitMeNow(strWhyExit)
  On Error Resume Next
  'Write why the exit is occurring
  LogStatus strWhyExit
  'Make sure we close the text file
  'that we opened
  objLogFile.Close
  If blnNotQuietMode Then
    MsgBox strWhyExit, vbCritical, "Error"
  End If
  'Quit running this script
  WScript.Quit
End Sub

'**************
'**** Main ****
'**************
On Error Resume Next

Dim strDate, strSource, strDest, strNewName, strExtension, strLogFileName, strTempDest
Dim fso, objFile, objLogFile
Dim intArg, intArgCount, intCopyMove, objArgs, blnNotQuietMode

'Initialize to string variables
strSource = vbNullString
strDest = vbNullString
strNewName = vbNullString
intCopyMove = 0

'Get the name of this file and append ".txt" to the end of it
'because it will be used to log status
strLogFileName = WScript.ScriptFullName
strLogFileName = Left(strLogFileName, Len(strLogFileName) - 4) & "_log.txt"

Set fso = CreateObject("Scripting.FileSystemObject")
'Open the text file for writing
Set objLogFile = fso.OpenTextFile(strLogFileName, 2, True)

'Get and format the date
strDate = FormatThisDate(Now())
'Log this information
LogStatus "File opened " & strDate & vbNewLine & "Checking arguments"

'Read arguments into object variable
Set objArgs = WScript.Arguments
'Get count of arguments
intArgCount = objArgs.Count - 1
'If not enough arguments were used
blnNotQuietMode = (intArgCount < 1)
'Loop through each argument and assign to a variable 
For intArg = 0 to intArgCount
  LogStatus "Setting argument " & intArg
  Select Case intArg
  Case 0
    strSource = objArgs(intArg)
  Case 1
    strDest = objArgs(intArg)
  Case 2
    intCopyMove = objArgs(intArg)
  Case 3
    strNewName = objArgs(intArg)
    'Exit loop here because we are
    'not interested in any other arguments
    Exit For
  End Select
Next

LogStatus "Checking source"
'If the string has no length, ask the user for it
If Len(strSource) = 0 Then
  LogStatus "Prompting user for source"
  strSource = InputBox("Source?")
  'If the string has no length, the user cancelled
  If Len(strSource) = 0 Then
    ExitMeNow "Source not set. User cancelled"
  End If
End If

If strSource = strDest Then
   ExitMeNow "Source and destination are the same"
End If

'If the file does not exist
If Not (fso.FileExists(strSource)) Then
   ExitMeNow strSource & " did not exist"
End If

LogStatus "Checking destination"
'If the string has no length, ask the user for it
If Len(strDest) = 0 Then
  LogStatus "Prompting user for destination"
  strDest = InputBox("Destination?")
  'If the string has no length, the user cancelled
  If Len(strDest) = 0 Then
    ExitMeNow "Destination not set. User cancelled"
  End If
End If

'Test strings for debugging only
'strNewName = "todaysdate"
'strNewName = "filesdate"

'If the last character in the string a backslash,
'append the date on to it
If Right(strDest, 1) = "\" Then
  LogStatus "Formatting destination string"
  'Get the source file's extension
  strExtension = "." & fso.GetExtensionName(strSource)
  Select Case LCase(strNewName)
  'If the new name variable is empty, or filesdate
  Case vbNullString, "filesdate"
    Set objFile = fso.GetFile(strSource)
    LogStatus "Last Modified " & objFile.DateLastModified
    strDate = FormatThisDate(objFile.DateLastModified)
    'Set new name equal to the soruce file's
    'date and source file's extension
    strNewName = strDate & strExtension
    Set objFile = Nothing
  Case "todaysdate"
    'Set new name equal to today's date
    'and source file's extension
    strNewName = strDate & strExtension
  Case "filestime"
    Set objFile = fso.GetFile(strSource)
    LogStatus "Last Modified " & objFile.DateLastModified
    'Set new name equal to the soruce file's
    'time and source file's extension
    strNewName = Replace(FormatDateTime(objFile.DateLastModified, vbShortTime), ":", vbNullString) & strExtension
    Set objFile = Nothing
  Case "todaystime"
    'Set new name equal to today's date
    'and source file's extension
    strNewName = Replace(FormatDateTime(Time, vbShortTime), ":", vbNullString) & strExtension
  End Select
  LogStatus "New name " & strNewName
  strDest = strDest & strNewName
End If

'If the destination file exists
If (fso.FileExists(strDest)) Then
  LogStatus "Deleting existing " & strDest
  'Delete the file or the MoveFile will error
  fso.DeleteFile strDest, True
End If

'If the destination file still exists
If (fso.FileExists(strDest)) Then
  ExitMeNow strDest & " already exists"
Else
  Select Case intCopyMove
  Case 0
    LogStatus "Copying " & strSource & " to " & strDest
    'Copy the source file to the destination
    fso.CopyFile strSource, strDest, True
  Case Else
    LogStatus "Renaming " & strSource & " to " & strDest
    'Rename the source file as the destination
    fso.MoveFile strSource, strDest
  End Select
End If

If (fso.FileExists(strDest)) Then
  LogStatus "Rename was successful"
Else
  LogStatus "Rename was not successful"
End If
LogStatus "Complete"
objLogFile.Close
